==> svps-2.0.0.tgz: package/lib/modules/prepare-files.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fs from 'fs';
import fsp from 'fs/promises';
import { join, relative as relativePath, dirname } from 'path';
import { ensureDir, uploadFile } from '../ssh.js';
import { fileURLToPath } from 'url';
import { basicPermissions } from './basic-permissions.js';
import { cwd } from './root.js';
const isDir = (path) => __awaiter(void 0, void 0, void 0, function* () {
    const stats = yield fsp.stat(path);
    return stats.isDirectory();
});
export const isFile = (path) => __awaiter(void 0, void 0, void 0, function* () {
    const stats = yield fsp.stat(path);
    return stats.isFile();
});
const formatSize = (bytes) => {
    if (bytes === 0)
        return '0KB';
    const k = 1024;
    const dm = 0;
    const sizes = [
        'B\x1b[36m',
        'K\x1b[34m',
        'M\x1b[33m',
        'G\x1b[35m',
        'T\x1b[31m',
        'P\x1b[31m',
        'E\x1b[31m',
        'Z\x1b[31m',
        'Y\x1b[31m',
    ];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return `${parseFloat((bytes / Math.pow(k, i)).toFixed(dm))}${sizes[i]}`;
};
const relative = (path) => relativePath(fileURLToPath(cwd), path).replace(/\.\.\//g, '');
const getContents = (dirPath, ignore) => __awaiter(void 0, void 0, void 0, function* () {
    const results = {
        dirs: [],
        files: [],
    };
    const readDir = (dir) => __awaiter(void 0, void 0, void 0, function* () {
        const entries = yield fsp.readdir(dir, { withFileTypes: true });
        for (const entry of entries) {
            if ([
                '.Trashes',
                '.Spotlight-V100',
                '.DS_Store',
                'Desktop.ini',
                '.localized',
                ...ignore,
            ].includes(entry.name))
                continue;
            const fullPath = join(dir, entry.name);
            if (yield isDir(fullPath)) {
                results.dirs.push(fullPath);
                yield readDir(fullPath);
            }
            else if (yield isFile(fullPath)) {
                const { size } = yield fsp.stat(fullPath);
                results.files.push({ path: fullPath, size: formatSize(size) });
            }
        }
    });
    yield readDir(dirPath);
    return results;
});
export const importFile = (path) => fs.readFileSync(path, 'utf-8');
export const upload = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { local, remote, blacklist, permissions } = options;
    if (yield isFile(local)) {
        const remoteDir = dirname(remote);
        console.log(`  \x1b[36m⌙\x1b[0m \x1b[0m\x1b[2mEnsuring the directory: \x1b[1m${remoteDir}\x1b[0m`);
        yield ensureDir(remoteDir);
        console.log(`    \x1b[36m⌙ \x1b[0m\x1b[2m${remote}\x1b[0m`);
        yield uploadFile(local, remote);
    }
    else if (yield isDir(local)) {
        const contents = yield getContents(local, blacklist || ['.git', 'node_modules']);
        const remoteDir = remote.replace(/\/$/, '');
        console.log(`  \x1b[36m⌙\x1b[0m \x1b[0m\x1b[2mEnsuring directories: \x1b[1m${remoteDir}\x1b[0m`);
        const longestSize = contents.files.reduce((max, entry) => Math.max(max, entry.size.length), 0);
        for (const dir of contents.dirs) {
            const currentDir = relative(dir);
            const remotePath = `${remoteDir}/${currentDir}`;
            /** Debug */
            // console.log('origin', dir);
            // console.log('expectedDir', currentDir);
            // console.log('remotePath', remotePath);
            // console.log();
            yield ensureDir(remotePath);
        }
        for (const file of contents.files) {
            const currentFile = relative(file.path).replace(/^\//, '');
            const remotePath = `${remoteDir}/${currentFile}`;
            /** Debug */
            // console.log('origin', file.path);
            // console.log('expectedFile', currentFile);
            // console.log('remotePath', remotePath);
            // console.log();
            const message = `    \x1b[36m⌙ \x1b[0m\x1b[2m${file.size.padStart(longestSize, ' ')} ■ \x1b[0m\x1b[2m${remotePath}\x1b[0m`;
            console.log(message);
            yield uploadFile(file.path, remotePath);
        }
    }
    if (permissions)
        yield basicPermissions(Object.assign({ remote }, permissions));
});
export const resourcesUpload = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { local, remote } = options;
    if (yield isFile(local)) {
        const remoteDir = dirname(remote);
        yield ensureDir(remoteDir);
        yield uploadFile(local, remote);
    }
});

==> svps-2.3.0.tgz: package/lib/modules/prepare-files.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fs from 'fs';
import fsp from 'fs/promises';
import { join, relative as relativePath, dirname } from 'path';
import { ensureDir, uploadFile } from '../ssh.js';
import { fileURLToPath } from 'url';
import { basicPermissions } from './basic-permissions.js';
import { cwd } from './root.js';
const isDir = (path) => __awaiter(void 0, void 0, void 0, function* () {
    const stats = yield fsp.stat(path);
    return stats.isDirectory();
});
export const isFile = (path) => __awaiter(void 0, void 0, void 0, function* () {
    const stats = yield fsp.stat(path);
    return stats.isFile();
});
const formatSize = (bytes) => {
    if (bytes === 0)
        return '0KB';
    const k = 1024;
    const dm = 0;
    const sizes = [
        'B\x1b[36m',
        'K\x1b[34m',
        'M\x1b[33m',
        'G\x1b[35m',
        'T\x1b[31m',
        'P\x1b[31m',
        'E\x1b[31m',
        'Z\x1b[31m',
        'Y\x1b[31m',
    ];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return `${parseFloat((bytes / Math.pow(k, i)).toFixed(dm))}${sizes[i]}`;
};
const relative = (path) => relativePath(fileURLToPath(cwd), path).replace(/\.\.\//g, '');
const getContents = (dirPath, ignore) => __awaiter(void 0, void 0, void 0, function* () {
    const results = {
        dirs: [],
        files: [],
    };
    const readDir = (dir) => __awaiter(void 0, void 0, void 0, function* () {
        const entries = yield fsp.readdir(dir, { withFileTypes: true });
        for (const entry of entries) {
            if ([
                '.Trashes',
                '.Spotlight-V100',
                '.DS_Store',
                'Desktop.ini',
                '.localized',
                ...ignore,
            ].includes(entry.name))
                continue;
            const fullPath = join(dir, entry.name);
            if (yield isDir(fullPath)) {
                results.dirs.push(fullPath);
                yield readDir(fullPath);
            }
            else if (yield isFile(fullPath)) {
                const { size } = yield fsp.stat(fullPath);
                results.files.push({ path: fullPath, size: formatSize(size) });
            }
        }
    });
    yield readDir(dirPath);
    return results;
});
export const importFile = (path) => fs.readFileSync(path, 'utf-8');
export const upload = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { local, remote, blacklist, permissions } = options;
    if (yield isFile(local)) {
        const remoteDir = dirname(remote);
        console.log(`  \x1b[36m⌙\x1b[0m \x1b[0m\x1b[2mEnsuring the directory: \x1b[1m${remoteDir}\x1b[0m`);
        yield ensureDir(remoteDir);
        console.log(`    \x1b[36m⌙ \x1b[0m\x1b[2m${remote}\x1b[0m`);
        yield uploadFile(local, remote);
    }
    else if (yield isDir(local)) {
        const contents = yield getContents(local, blacklist || ['.git', 'node_modules']);
        const remoteDir = remote.replace(/\/$/, '');
        console.log(`  \x1b[36m⌙\x1b[0m \x1b[0m\x1b[2mEnsuring directories: \x1b[1m${remoteDir}\x1b[0m`);
        const longestSize = contents.files.reduce((max, entry) => Math.max(max, entry.size.length), 0);
        for (const dir of contents.dirs) {
            const currentDir = relative(dir);
            const remotePath = `${remoteDir}/${currentDir}`;
            /** Debug */
            // console.log('origin', dir);
            // console.log('expectedDir', currentDir);
            // console.log('remotePath', remotePath);
            // console.log();
            yield ensureDir(remotePath);
        }
        yield Promise.all(contents.files.map((file) => {
            const currentFile = relative(file.path).replace(/^\//, '');
            const remotePath = `${remoteDir}/${currentFile}`;
            /** Debug */
            // console.log('origin', file.path);
            // console.log('expectedFile', currentFile);
            // console.log('remotePath', remotePath);
            // console.log();
            const message = `    \x1b[36m⌙ \x1b[0m\x1b[2m${file.size.padStart(longestSize, ' ')} ■ \x1b[0m\x1b[2m${remotePath}\x1b[0m`;
            console.log(message);
            return uploadFile(file.path, remotePath);
        }));
    }
    if (permissions)
        yield basicPermissions(Object.assign({ remote }, permissions));
});
export const resourcesUpload = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { local, remote } = options;
    if (yield isFile(local)) {
        const remoteDir = dirname(remote);
        yield ensureDir(remoteDir);
        yield uploadFile(local, remote);
    }
});
